# MBASIC Utilities Library

Utility programs for file management, conversion, and system tools

## Available Utilities

### Bigcal2



**Year:** 1980s
**Tags:** 

**[Download bigcal2.bas](bigcal2.bas)**

---

### Calendar



**Year:** 1980s
**Tags:** 

**[Download calendar.bas](calendar.bas)**

---

### Calendr5



**Year:** 1980s
**Tags:** 

**[Download calendr5.bas](calendr5.bas)**

---

### Charfreq



**Year:** 1980s
**Tags:** 

**[Download charfreq.bas](charfreq.bas)**

---

### Convert



**Year:** 1980s
**Tags:** 

**[Download convert.bas](convert.bas)**

---

### Dow



**Year:** 1980s
**Tags:** 

**[Download dow.bas](dow.bas)**

---

### Fprime



**Year:** 1980s
**Tags:** 

**[Download fprime.bas](fprime.bas)**

---

### Remarks:  This program will con



**Year:** 1980s
**Tags:** 

**[Download hex2data.bas](hex2data.bas)**

---

### Million



**Year:** 1980s
**Tags:** 

**[Download million.bas](million.bas)**

---

### Rotate



**Year:** 1980s
**Tags:** 

**[Download rotate.bas](rotate.bas)**

---

### Search



**Year:** 1980s
**Tags:** 

**[Download search.bas](search.bas)**

---

### Sort



**Year:** 1980s
**Tags:** 

**[Download sort.bas](sort.bas)**

---

### Ucase



**Year:** 1980s
**Tags:** 

**[Download ucase.bas](ucase.bas)**

---

### Un-Prot

Fixup for ** UN.COM **

**Year:** 1980s
**Tags:** 

**[Download un-prot.bas](un-prot.bas)**

---

### Unprotct



**Year:** 1980s
**Tags:** 

**[Download unprotct.bas](unprotct.bas)**

---

### Uudecode



**Year:** 1980s
**Tags:** 

**[Download uudecode.bas](uudecode.bas)**

---

### Xextract

0 -->END PAGE / 1-20 -->EXTRACT ITEM / 21 -->RESTART

**Year:** 1980s
**Tags:** 

**[Download xextract.bas](xextract.bas)**

---

### Xscan

0 -->END PAGE / 1-20 -->DELETE ITEM / 21 -->RESTART

**Year:** 1980s
**Tags:** 

**[Download xscan.bas](xscan.bas)**

---

## How to Use

1. **Download** the .bas file you want to use
2. **Open MBASIC** in your preferred UI (Web, Tkinter, Curses, or CLI)
3. **Load the file:**
   - **Web/Tkinter UI:** Click File → Open, select the downloaded file
   - **CLI:** Type `LOAD "filename.bas"`
4. **Run:** Type `RUN` or press the Run button

## About These Utilities

These programs are from the CP/M and early PC era (1970s-1980s), 
preserved from historical archives including OAK, Simtel, and CP/M CD-ROMs.
